==> thx_cms_box-0.1.13-py3-none-any.whl: thx/cms/box/settings.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

CMS_BOX_SECTION_CHILD_CLASSES = ['BoxPlugin', 'ModelBoxPlugin', 'FilterBoxPlugin']
CMS_BOX_BOX_CHILD_CLASSES = ['BoxPlugin',]

CMS_BOX_SECTION_TEMPLATE_CHOICES = (
    ('cms/box/section.html', _('Section Template'),),
)
CMS_BOX_SECTION_TEMPLATE_DEFAULT = 'cms/box/section.html'

CMS_BOX_SECTION_IMAGE_CROPPING = '1920x1000'
CMS_BOX_SECTION_MOBILE_IMAGE_CROPPING = '640x900'

CMS_BOX_BOX_IMAGE_CROPPING = '1920x1000'
CMS_BOX_BOX_MOBILE_IMAGE_CROPPING = '640x900'

CMS_BOX_BOX_TEMPLATE_CHOICES = (
    ('cms/box/box.html', _('Box Template'),),
)
CMS_BOX_BOX_TEMPLATE_DEFAULT = 'cms/box/box.html'

CMS_BOX_MODEL_BOX_TEMPLATE_CHOICES = (
    ('cms/box/model_box.html', _('ModelBox Template'),),
)
CMS_BOX_MODEL_BOX_TEMPLATE_DEFAULT = 'cms/box/model_box.html'
CMS_BOX_MODEL_BOX_FILTER_CHOICES = ()
CMS_BOX_MODEL_BOX_ORDER_BY_DEFAULT = '-date_create, title'
CMS_BOX_MODEL_BOX_OBJECTS_NUMBER_DEFAULT = 4

CMS_BOX_FILTER_BOX_TEMPLATE_CHOICES = (
    ('cms/box/filter_box.html', _('FilterBox Template'),),
)
CMS_BOX_FILTER_BOX_TEMPLATE_DEFAULT = 'cms/box/filter_box.html'

CMS_BOX_SECTION_ORDER_BY_DEFAULT = 'ordering'

BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': (
            'status', 'title', 'slug', 'template_name', 'description', 'image', 'first_cta_label',
            'first_cta_link', 'second_cta_label', 'second_cta_link', 'third_cta_label',
            'third_cta_link', 'external_cta_label', 'external_cta_link', 'ordering',
        )
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

MODEL_BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': (
            'status', 'title', 'slug', 'template_name', 'filter', 'order_by', 'objects_number', 'typology', 'tags'
        )
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

FILTER_BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': ('status', 'title', 'slug', 'template_name')
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

SECTION_ADMIN = {}
SECTION_CROPPING = {}
SECTION_CROPPING_MOBILE = {}

BOX_ADMIN = {}
BOX_CROPPING = {}
BOX_CROPPING_MOBILE = {}

MODEL_BOX_ADMIN = {}
MODEL_BOX_CROPPING = {}
MODEL_BOX_CROPPING_MOBILE = {}

FILTER_BOX_ADMIN = {}
FILTER_BOX_CROPPING = {}
FILTER_BOX_CROPPING_MOBILE = {}

# ORDER_BY
CMS_BOX_SECTION_ORDER_BY_DEFAULT_FIELDS = [
    'ordering', '-ordering', 'date_create', '-date_create',
]
CMS_BOX_SECTION_ORDER_BY_FIELDS = {}

CMS_BOX_MODELBOX_ORDER_BY_DEFAULT_FIELDS = [
    'ordering', '-ordering', 'date_create', '-date_create',
]
CMS_BOX_MODELBOX_ORDER_BY_FIELDS = {}

==> thx_cms_box-0.1.16-py3-none-any.whl: thx/cms/box/settings.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

CMS_BOX_SECTION_CHILD_CLASSES = ['BoxPlugin', 'ModelBoxPlugin', 'FilterBoxPlugin']
CMS_BOX_BOX_CHILD_CLASSES = ['BoxPlugin',]

CMS_BOX_SECTION_TEMPLATE_CHOICES = (
    ('cms/box/section.html', _('Section Template'),),
)
CMS_BOX_SECTION_TEMPLATE_DEFAULT = 'cms/box/section.html'

CMS_BOX_SECTION_IMAGE_CROPPING = '1920x1000'
CMS_BOX_SECTION_MOBILE_IMAGE_CROPPING = '640x900'

CMS_BOX_BOX_IMAGE_CROPPING = '1920x1000'
CMS_BOX_BOX_MOBILE_IMAGE_CROPPING = '640x900'

CMS_BOX_BOX_TEMPLATE_CHOICES = (
    ('cms/box/box.html', _('Box Template'),),
)
CMS_BOX_BOX_TEMPLATE_DEFAULT = 'cms/box/box.html'

CMS_BOX_MODEL_BOX_TEMPLATE_CHOICES = (
    ('cms/box/model_box.html', _('ModelBox Template'),),
)
CMS_BOX_MODEL_BOX_TEMPLATE_DEFAULT = 'cms/box/model_box.html'
CMS_BOX_MODEL_BOX_FILTER_CHOICES = ()
CMS_BOX_MODEL_BOX_ORDER_BY_DEFAULT = '-date_create'
CMS_BOX_MODEL_BOX_OBJECTS_NUMBER_DEFAULT = 4

CMS_BOX_FILTER_BOX_TEMPLATE_CHOICES = (
    ('cms/box/filter_box.html', _('FilterBox Template'),),
)
CMS_BOX_FILTER_BOX_TEMPLATE_DEFAULT = 'cms/box/filter_box.html'

CMS_BOX_SECTION_ORDER_BY_DEFAULT = 'ordering'

BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': (
            'status', 'title', 'slug', 'template_name', 'description', 'image', 'first_cta_label',
            'first_cta_link', 'second_cta_label', 'second_cta_link', 'third_cta_label',
            'third_cta_link', 'external_cta_label', 'external_cta_link', 'ordering',
        )
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

MODEL_BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': (
            'status', 'title', 'slug', 'template_name', 'filter', 'order_by', 'objects_number', 'typology', 'tags'
        )
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

FILTER_BOX_ADMIN_NO_PARENT = (
    (_('general information'), {
        'fields': ('status', 'title', 'slug', 'template_name')
    }),
    (_('logs admin'), {
        'classes': ('collapse',),
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    }),
)

SECTION_ADMIN = {}
SECTION_CROPPING = {}
SECTION_CROPPING_MOBILE = {}

BOX_ADMIN = {}
BOX_CROPPING = {}
BOX_CROPPING_MOBILE = {}

MODEL_BOX_ADMIN = {}
MODEL_BOX_CROPPING = {}
MODEL_BOX_CROPPING_MOBILE = {}

FILTER_BOX_ADMIN = {}
FILTER_BOX_CROPPING = {}
FILTER_BOX_CROPPING_MOBILE = {}

# ORDER_BY
CMS_BOX_SECTION_ORDER_BY_DEFAULT_FIELDS = [
    'ordering', '-ordering', 'date_create', '-date_create',
]
CMS_BOX_SECTION_ORDER_BY_FIELDS = {}

CMS_BOX_MODELBOX_ORDER_BY_DEFAULT_FIELDS = [
    'ordering', '-ordering', 'date_create', '-date_create',
]
CMS_BOX_MODELBOX_ORDER_BY_FIELDS = {}
